==> myriad-squire-client-1.0.1-8b507f.tar: src/SquireConfiguration.php <==
<?php namespace Myriad\Squire;

use Illuminate\Contracts\Cache\Repository;

class SquireConfiguration {

  const CACHE_KEY = 'squire-provision';

  /**
   * @var array Holds the configuration
   */
  private $config;

  /**
   * @var \Illuminate\Contracts\Cache\Repository The configuration repository
   */
  private $cache;

  /**
   * Create a new Squire Configuration Manager
   *
   * @param array $config
   * @param \Illuminate\Contracts\Cache\Repository $cache
   */
  public function __construct($config, Repository $cache) {

    // load server token
    if (empty($config['server_token'])) {
      throw new \InvalidArgumentException('Configuration must contain server_token');
    }

    // load server url
    if (empty($config['server_url'])) {
      throw new \InvalidArgumentException('Configuration must contain server_url');
    }

    $this->config = $config;

    $this->cache = $cache;
  }

  /**
   * Load the provisioning information from cache or the Squire server
   */
  public function provision() {
    $config = $this->cache->get(self::CACHE_KEY, []);

    if (empty($config)) {
      $client = new \GuzzleHttp\Client();
      $response = $client->get(rtrim($this->getServerUrl(), "/") . '/api/v1/provision', [
        'headers' => [
          'Authorization' => $this->getServerToken()
        ]
      ]);
      $config = $response->json();
      $this->cache->forever(self::CACHE_KEY, $config);
    }

    $this->config = array_merge($config, $this->config);
  }

  /**
   * @return string the server token
   */
  public function getServerToken() {
    return $this->config['server_token'];
  }

  /**
   * @return string the Squire server url
   */
  public function getServerUrl() {
    return $this->config['server_url'];
  }

  /**
   * @param string $key the provisioning configuration value
   *
   * @return string the configuration value
   */
  private function getProvisionedValue($key) {
    if (!isset($this->config[$key])) {
      $this->provision();
    }

    return $this->config[$key];
  }

  /**
   * @return string The application's prefix
   */
  public function getPrefix() {
    return $this->getProvisionedValue('prefix');
  }

  /**
   * @return string The image domain
   */
  public function getDomain() {
    return $this->getProvisionedValue('domain');
  }

  /**
   * @return bool True when images should be signed
   */
  public function isPrivate() {
    return $this->getProvisionedValue('private');
  }

}

==> myriad-squire-client-1.0.5-67139f.tar: src/SquireConfiguration.php <==
<?php namespace Myriad\Squire;

use GuzzleHttp\Client as Guzzle;
use Illuminate\Contracts\Cache\Repository;

class SquireConfiguration {

  const CACHE_KEY = 'squire-provision';

  /**
   * @var array Holds the configuration
   */
  private $config;

  /**
   * @var \Illuminate\Contracts\Cache\Repository The configuration repository
   */
  private $cache;

  /**
   * @var \GuzzleHttp\Client The Guzzle client used for provisioning
   */
  private $guzzle;

  /**
   * Create a new Squire Configuration Manager
   *
   * @param array $config
   * @param \Illuminate\Contracts\Cache\Repository $cache
   * @param \GuzzleHttp\Client $guzzle
   */
  public function __construct($config, Repository $cache, Guzzle $guzzle) {

    // load server token
    if (empty($config['server_token'])) {
      throw new \InvalidArgumentException('Configuration must contain server_token');
    }

    // load server url
    if (empty($config['server_url'])) {
      throw new \InvalidArgumentException('Configuration must contain server_url');
    }

    $this->config = $config;

    $this->cache = $cache;

    $this->guzzle = $guzzle;
  }

  /**
   * Load the configuration information from cache or the Squire server
   */
  public function provision() {
    $config = $this->cache->get(self::CACHE_KEY, []);

    if (empty($config)) {
      $response = $this->guzzle->get(rtrim($this->getServerUrl(), "/") . '/api/v1/provision', [
        'headers' => [
          'Authorization' => $this->getServerToken()
        ]
      ]);
      $config = $response->json();
      $this->cache->forever(self::CACHE_KEY, $config);
    }

    $this->config = array_merge($config, $this->config);
  }

  /**
   * @return string the server token
   */
  public function getServerToken() {
    return $this->config['server_token'];
  }

  /**
   * @return string the Squire server url
   */
  public function getServerUrl() {
    return $this->config['server_url'];
  }

  /**
   * @param string $key the provisioning configuration value
   *
   * @return string the configuration value
   */
  private function getProvisionedValue($key) {
    if (!isset($this->config[$key])) {
      $this->provision();
    }

    return $this->config[$key];
  }

  /**
   * @return string The application's prefix
   */
  public function getPrefix() {
    return $this->getProvisionedValue('prefix');
  }

  /**
   * @return string The image domain
   */
  public function getDomain() {
    return $this->getProvisionedValue('domain');
  }

  /**
   * @return bool True when images should be signed
   */
  public function isPrivate() {
    return $this->getProvisionedValue('private');
  }

}
